@@ -3,7 +3,6 @@ import json
 import gi
 import os
 import base64
-from ..models.AppListElement import AppListElement
 
 gi.require_version('Gtk', '4.0')
 gi.require_version('Adw', '1')
@@ -25,10 +24,10 @@ def set_json_config(name: str, data):
     path = f'{GLib.get_user_config_dir()}/{name}.json'
 
     with open(path, 'w+') as file:
-        file.write(json.dumps(data))
+        file.write(json.dumps(data, indent=4))
         logging.info(f'Saving config to {path}')
 
-def read_config_for_app(el: AppListElement) -> dict:
+def read_config_for_app(el) -> dict:
     conf = read_json_config('apps')
     b64name = base64.b64encode(el.name.encode('utf8')).decode('ascii')
 
@@ -37,6 +36,18 @@ def read_config_for_app(el: AppListElement) -> dict:
 
     return app_config
 
+def remove_update_config(el):
+    app_conf = read_config_for_app(el)
+
+    refresh_config = False
+    for c in ['update_url', 'update_url_manager', 'update_manager_config']:
+        if c in app_conf:
+            refresh_config = True
+            del app_conf[c]
+
+    if refresh_config:
+        save_config_for_app(app_conf)
+
 def save_config_for_app(app_conf):
     conf = read_json_config('apps')
     app_conf['name'] = (base64.b64decode(app_conf['b64name'])).decode('utf8')
